/*
 *  upkg: tool for manipulating Unreal Tournament packages.
 *  Copyright (C) 2009 Nick Bowler
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef UOBJECT_LOADABLE_H_
#define UOBJECT_LOADABLE_H_

#include <stdio.h>
#include <glib-object.h>

#define UOBJECT_TYPE_LOADABLE (uobject_loadable_get_type())
#define UOBJECT_LOADABLE(obj) G_TYPE_CHECK_INSTANCE_CAST(obj, \
	UOBJECT_TYPE_LOADABLE, UObjectLoadable)
#define UOBJECT_IS_LOADABLE(obj) G_TYPE_CHECK_INSTANCE_TYPE(obj, \
	UOBJECT_TYPE_LOADABLE)
#define UOBJECT_LOADABLE_GET_INTERFACE(inst) G_TYPE_INSTANCE_GET_INTERFACE \
	(inst, UOBJECT_TYPE_LOADABLE, UObjectLoadable)

typedef struct UObjectLoadable UObjectLoadable;

/*
 * Interface for UObjects supporting "load" and "unload".  These are generally
 * objects that need to allocate large amounts of memory in order to be
 * useful -- textures and sounds, for example -- where you might want to keep
 * around instances but the actual texture or sound data is not needed.
 */
struct UObjectLoadable {
	GTypeInterface parent;

	int (*load)(GObject *obj);
	void (*unload)(GObject *obj);
};

GType uobject_loadable_get_type(void);

int uobject_load(GObject *obj);
void uobject_unload(GObject *obj);

#endif
